@@ -1,5 +1,5 @@
 /*
-** Copyright 2000-2002 Double Precision, Inc.
+** Copyright 2000-2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 #include	"config.h"
@@ -240,7 +240,7 @@ static void sslerror(const struct tls_info *info, const char *pfix, int rc)
 	{
 		if (rc == 0)
 		{
-			(*info->tls_err_msg)("Unexpected SSL connection shutdown.",
+			(*info->tls_err_msg)("DEBUG: Unexpected SSL connection shutdown.",
 					     info->app_data);
 			return;
 		}
@@ -493,7 +493,7 @@ SSL_CTX *tls_create(int isserver, const struct tls_info *info)
 				FILE *fp;
 
 				p=strrchr(de->d_name, '.');
-				if (!p[0] || !p[1])
+				if (!p || !p[1])
 					continue;
 				while (*++p)
 				{
@@ -619,7 +619,7 @@ static int cache_add(SSL *ssl, SSL_SESSION *sess)
 		sizeof(session_id_len)+session_id_len;
 
 	i2d_SSL_SESSION(sess, &ucp);
-	if (tls_cache_add(info->tlscache, buffer,
+	if (tls_cache_add(info->tlscache, (char *)buffer,
 			  (size_t)(sizeof(timeout) +
 				   sizeof(session_id_len) +
 				   session_id_len + sess_len)))
@@ -691,7 +691,8 @@ static int get_func(void *rec, size_t recsize,
 
 	sess=recp + sizeof(timeout) + sizeof(session_id_len) + session_id_len;
 
-	wi->ret=d2i_SSL_SESSION(NULL, &sess, recsize - sizeof(timeout) -
+	wi->ret=d2i_SSL_SESSION(NULL, (const unsigned char **)
+				&sess, recsize - sizeof(timeout) -
 				sizeof(session_id_len) - session_id_len);
 
 	*wi->copyflag=0;
@@ -1044,3 +1045,11 @@ int	tls_transfer(struct tls_transfer_info *t, SSL *ssl, int fd,
 
 	return (1);
 }
+
+int tls_connecting(SSL *ssl)
+{
+	struct tls_info *info=(struct tls_info *)SSL_get_app_data(ssl);
+
+	return info->accept_interrupted || info->connect_interrupted;
+}
+
